AESDecryption class

Class responsible for AES decryption of data.

Constructors

AESDecryption({required String encryptionKey, AESMode? mode, String? padding})
Constructor for AESDecryption class.

Properties

accessKey ↔ String
getter/setter pair
decrypt → Future
Asynchronously decrypts the encryptedValue.
no setter
encryptedValue ↔ dynamic
getter/setter pair
encryptionKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
mode → AESMode?
final
padding → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aesDecrypt(String secretKey, Encrypted encryptedValue) → String
Decrypts encryptedValue using AES decryption with the provided secretKey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited