EncryptionConstants class

A class that holds constants related to encryption.

This class contains static constant values used throughout the application for encryption purposes.

Constructors

EncryptionConstants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

encryptionMapKey → const String
The key used to store and retrieve encryption mappings in SharedPreferences.