FernetEncryption class

A class to handle Fernet encryption for a given value and key.

Constructors

FernetEncryption({required String encryptionKey, required String accessKey})
Constructs a FernetEncryption instance with the given encryptionKey and accessKey.

Properties

accessKey → String
The access key used to identify the encrypted value in shared preferences.
final
encrypt → dynamic
Encrypts the value using the Fernet encryption algorithm.
no setter
encryptionKey → String
The encryption key used for encrypting the value.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
The value to be encrypted.
getter/setter pair

Methods

fernetEncrypt(String secretKey, String value) → Future<String>
Encrypts the given value with the provided secretKey using the Fernet encryption algorithm.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited