Salsa20Decryption class

Class responsible for Salsa20 decryption of data.

Constructors

Salsa20Decryption({required String encryptionKey})
Constructor for Salsa20Decryption class.

Properties

accessKey ↔ String
getter/setter pair
decrypt → Future
Asynchronously decrypts the encryptedValue.
no setter
encryptedValue ↔ dynamic
getter/setter pair
encryptionKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
salsa20Decrypt(String secretKey, Encrypted encryptedValue) → String
Decrypts encryptedValue using Salsa20 decryption with the provided secretKey.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited