Salsa20Encryption class

Class responsible for Salsa20 encryption of data.

Constructors

Salsa20Encryption({required String encryptionKey})
Constructor for Salsa20Encryption class.

Properties

accessKey ↔ String
getter/setter pair
encrypt → Future<String>
Asynchronously encrypts the value.
no setter
encryptionKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
salsa20Encrypt(String secretKey, String value) → Future<String>
Encrypts value using Salsa20 encryption with the provided secretKey.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited